"use strict";
/*
 * Copyright (c) 2021, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.hasUnsupportedFeatures = exports.metadataTypes = exports.settings = exports.features = void 0;
/**
 * when checking for completeness or building registries
 * this is the list of features that are not available,
 * typically because the devhub doesn't support them, so we can't use metadataDescribe
 *
 * */
exports.features = [
    // ERROR running force:org:create: * is not a valid Features value.
    'SERVICECATALOG',
    'DYNAMICATTRIBUTES',
    'CONTRACTMGMT',
    'CUSTOMIZABLENAMEDCREDENTIALS',
    'INDUSTRIESMFGPROGRAMPILOT',
    'HEALTHCLOUDHPIBETA',
    'MANAGETIMELINE',
    'HEALTHCLOUDBETA',
    'PARDOTADVANCED',
    'MCONTENTMETADATA',
    'EMBEDDEDSERVICEMESSAGING',
    'ARCGRAPHCOMMUNITY',
    'UNIFIEDHEALTHSCORING',
    'HEALTHCLOUDADDON',
    'EINSTEINDOCREADER',
];
exports.settings = [
    'botSettings', // have not successfully deployed this because of licensing errors when deploying settings
];
exports.metadataTypes = [
    // things that don't show up in describe so far
    'PicklistValue',
    // two children of GlobalValueSet
    'CustomValue',
    'StandardValue',
    // the following are not describable based on their features/settings, last checked 2/24/2022
    'DiscoveryStory',
    'EmployeeDataSyncProfile',
    'RelatedRecordAssocCriteria',
    'ScoreRange',
    'WorkflowFlowAction',
];
const hasUnsupportedFeatures = (type) => {
    if (!type.orgShapes?.developer) {
        return true;
    }
    if (type.orgShapes.developer.features?.length &&
        exports.features.some((feature) => type.orgShapes?.developer.features.includes(feature))) {
        return true;
    }
    return type.orgShapes?.developer.settings && exports.settings.some((setting) => type.orgShapes?.developer.settings[setting]);
};
exports.hasUnsupportedFeatures = hasUnsupportedFeatures;
//# sourceMappingURL=nonSupportedTypes.js.map